==> onu-clara-facade-0.0.12.tgz: package/src/clara-animation.js <==
export default class ClaraAnimation {
  activeAnimation = null;

  constructor(claraApi) {
    this.claraApi = claraApi;
  }

  getClips = () => {
    return this.claraApi.animation.getClips();
  };

  playClip = (clipName, playInReverse) => {
    const clip = this.getClipByName(clipName);
    if (!clip) {
      console.error(`Cannot find animation name ${clipName}`);
      return;
    }
    this.jumpToStartFrame(clip, playInReverse);
    this.activeAnimation = clipName;

    this.claraApi.animation.queueClip(clip.id, {
      autoplay: true,
      playSpeed: playInReverse ? -1 : 1
    });
  };

  getClipByName = clipName => {
    if (!clipName) {
      return null;
    }
    const clips = this.claraApi.animation.getClips();
    const selectedClipIndex = clips.findIndex(clip => clip.name === clipName);
    if (selectedClipIndex === -1) {
      console.error(`Could not find animation clip with name "${clipName}"`);
      return null;
    }
    return clips[selectedClipIndex];
  };

  jumpToStartFrame = (clip, playInReverse) => {
    this.stopAllAnimation();
    if (this.activeAnimation && this.activeAnimation !== clip.name) {
      // Reset previous animation before playing new one
      this.setClipToStartOrEnd(this.getClipByName(this.activeAnimation), false);
    }
    this.setClipToStartOrEnd(clip, playInReverse);
  };

  setClipToStartOrEnd = (clip, playInReverse) => {
    clip.tracks.forEach(track => {
      this.setTrackToStartOrEnd(track, clip, playInReverse);
    });
  };

  setTrackToStartOrEnd = (track, clip, playInReverse) => {
    const trackPath = track.path;
    const path = Array.isArray(trackPath) ? trackPath : this.claraApi.scene.find(trackPath);
    if (!path) {
      return;
    }
    let value = playInReverse ? track.value : track.startValue;
    if (!value) {
      const vs = track.keyframes.vs;
      if (vs) {
        value = vs[playInReverse ? vs.length - 1 : 0];
      } else {
        value = {};
        const keys = Object.keys(track.keyframes);
        keys.forEach(key => {
          value[key] = track.keyframes[key].vs[playInReverse ? track.keyframes[key].vs.length - 1 : 0];
        });
      }
    }
    const setFn = clip.set ? clip.set : this.claraApi.sceneGraph.set;
    setFn(path, value);
  };

  resetAllAnimations = () => {
    this.stopAllAnimation();
    this.activeAnimation = null;
    const clips = this.claraApi.animation.getClips();
    clips.forEach(clip => {
      this.setClipToStartOrEnd(clip, false);
    });
  };

  stopAllAnimation = () => {
    if (this.activeAnimation) {
      this.claraApi.animation.removeAnimation(this.activeAnimation);
    }
    this.claraApi.animation.stopPlaying();
  };
}

==> onu-clara-facade-0.17.0.tgz: package/src/clara-animation.js <==
export default class ClaraAnimation {
  activeAnimation = null;

  constructor(claraApi) {
    this.claraApi = claraApi;
  }

  getClips = () => {
    return this.claraApi.animation.getClips();
  };

  playClip = (clipName, playInReverse) => {
    const clip = this.getClipByName(clipName);
    if (!clip) {
      console.error(`Cannot find animation name ${clipName}`);
      return;
    }
    this.jumpToStartFrame(clip, playInReverse);
    this.activeAnimation = clipName;

    this.claraApi.animation.queueClip(clip.id, {
      autoplay: true,
      playSpeed: playInReverse ? -1 : 1
    });
  };

  getClipByName = (clipName) => {
    if (!clipName) {
      return null;
    }
    const clips = this.claraApi.animation.getClips();
    const selectedClipIndex = clips.findIndex((clip) => clip.name === clipName);
    if (selectedClipIndex === -1) {
      console.error(`Could not find animation clip with name "${clipName}"`);
      return null;
    }
    return clips[selectedClipIndex];
  };

  jumpToStartFrame = (clip, playInReverse) => {
    this.stopAllAnimation();
    if (this.activeAnimation && this.activeAnimation !== clip.name) {
      // Reset previous animation before playing new one
      this.setClipToStartOrEnd(this.getClipByName(this.activeAnimation), false);
    }
    this.setClipToStartOrEnd(clip, playInReverse);
  };

  setClipToStartOrEnd = (clip, playInReverse) => {
    clip.tracks.forEach((track) => {
      this.setTrackToStartOrEnd(track, clip, playInReverse);
    });
  };

  setTrackToStartOrEnd = (track, clip, playInReverse) => {
    const trackPath = track.path;
    const path = Array.isArray(trackPath) ? trackPath : this.claraApi.scene.find(trackPath);
    if (!path) {
      return;
    }
    let value = playInReverse ? track.value : track.startValue;
    if (!value) {
      const vs = track.keyframes.vs;
      if (vs) {
        value = vs[playInReverse ? vs.length - 1 : 0];
      } else {
        value = {};
        const keys = Object.keys(track.keyframes);
        keys.forEach((key) => {
          value[key] = track.keyframes[key].vs[playInReverse ? track.keyframes[key].vs.length - 1 : 0];
        });
      }
    }
    const setFn = clip.set ? clip.set : this.claraApi.sceneGraph.set;
    setFn(path, value);
  };

  resetAllAnimations = () => {
    this.stopAllAnimation();
    this.activeAnimation = null;
    const clips = this.claraApi.animation.getClips();
    clips.forEach((clip) => {
      this.setClipToStartOrEnd(clip, false);
    });
  };

  stopAllAnimation = () => {
    if (this.activeAnimation) {
      this.claraApi.animation.removeAnimation(this.activeAnimation);
    }
    this.claraApi.animation.stopPlaying();
  };
}
